package de.sh_edraft.config

import java.net.InetAddress
import java.net.UnknownHostException
import java.util.*
import java.util.logging.Logger


class Config(private var logger: Logger) {
    private val properties = Properties()

    var hostName: String = ""
        get() {
            return this.getHostname() ?: "localhost"
        }
        private set

    var environment: String = ""
        get() {
            return System.getenv("PLUGIN_ENVIRONMENT") ?: "production"
        }
        private set

    lateinit var ApiURL: String
        private set

    lateinit var ApiKey: String
        private set

    private fun getHostname(): String? {
        try {
            return InetAddress.getLocalHost().hostName
        } catch (ex: UnknownHostException) {
            println("Hostname can not be resolved")
        }
        return null
    }

    fun read(filename: String, optional: Boolean = false) {
        logger.config("Try to read config ${filename}")
        var foundFile = false
        try {
            val file = this::class.java.getResourceAsStream(filename)
            if (file == null && optional) {
                logger.config("${filename} not found")
                return
            }
            this.properties.load(file)
            logger.info("Found config ${filename}")
            foundFile = true
        } catch (e: Exception) {
            this.logger.warning("Error loading ${filename}")
        }

        if (!foundFile) {
            return
        }
        try {
            this.ApiURL = this.getProperty("apiURL").toString()
            this.ApiKey = this.getProperty("apiKey").toString()
        } catch (e: Exception) {
            this.logger.severe("Error loading config")
        }
    }

    private fun getProperty(key: String): String? {
        return this.properties.getProperty(key)
    }
}